/*
 * This file is part of Locutil2.
 * 
 * Copyright (c) 2007 Thomas King <king@informatik.uni-mannheim.de>,
 * University of Mannheim, Germany
 * 
 * All rights reserved.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.locutil2.trace;

import org.pi4.locutil1.MACAddress;
import org.pi4.locutil2.GeoPosition;

/**
 * Data entry.
 * 
 * @author faerber
 * @author king
 */
public class TraceEntry {
	private long timestamp;
	private GeoPosition position;
	private MACAddress id;
	private SignalStrengthSamples samples;
	
	/**
	 * Creates a new data entry object.
	 * 
	 * @param timestamp	time of recording
	 * @param position	the position
	 * @param id	MAC of recording device
	 * @param samples	signal strength samples
	 * @param channel	wireless lan channel of AP
	 */
	public TraceEntry(long timestamp, GeoPosition position, MACAddress id, SignalStrengthSamples samples) {
		this.timestamp = timestamp;
		this.position = position;
		this.id = id;
		this.samples = samples;
	}
	
	/**
	 * Creates an empty data entry object.
	 */
	public TraceEntry() {
		this.position = new GeoPosition();
		this.timestamp = -1;
		this.id = new MACAddress(new short[]{0, 0, 0, 0, 0, 0});
		this.samples = new SignalStrengthSamples();
	}
	
	/**
	 * Returns the timestamp.
	 * 
	 * @return	the timestamp
	 */
	public long getTimestamp() {
		return timestamp;
	}
	
	/**
	 * Sets the timestamp
	 * 
	 * @param timestamp	the timestamp
	 */
	public void setTimestamp(long timestamp) {
		this.timestamp = timestamp;
	}
	
	/**
	 * Returns the position.
	 * 
	 * @return	the position
	 */
	public GeoPosition getGeoPosition() {
		return position;
	}
	
	/**
	 * Sets the position.
	 * 
	 * @param position	the position
	 */
	public void setGeoPosition(GeoPosition position) {
		this.position = position;
	}
	
	/**
	 * Returns the MAC of the network card that has been used to sample the data.
	 * 
	 * @return	the MAC
	 */
	public MACAddress getId() {
		return id;
	}
	
	/**
	 * Sets the MAC of the network card that has been used to sample the data.
	 * 
	 * @param id	the MAC
	 */
	public void setId(MACAddress id) {
		this.id = id;
	}
	
	/**
	 * Returns the signal strength samples.
	 * 
	 * @return	the samples
	 */
	public SignalStrengthSamples getSignalStrengthSamples() {
		return samples;
	}
	
	public TraceEntry clone() {
		TraceEntry returnme = new TraceEntry(this.getTimestamp(), this.getGeoPosition(), this.getId(), this.getSignalStrengthSamples());
		return returnme;
	}
	
	public String toString() {
		StringBuffer sb = new StringBuffer();
		sb.append("t=");
		sb.append(getTimestamp());
		sb.append(";id=");
		sb.append(getId());
		sb.append(";pos=");
		sb.append(getGeoPosition().getX());
		sb.append(",");
		sb.append(getGeoPosition().getY());
		sb.append(",");
		sb.append(getGeoPosition().getZ());
		sb.append(";degree=");
		sb.append(getGeoPosition().getOrientation());
		sb.append(samples);
		return sb.toString();
	}
}
