/*
 * This file is part of Locutil2.
 * 
 * Copyright (c) 2007 Thomas King <king@informatik.uni-mannheim.de>,
 * University of Mannheim, Germany
 * 
 * All rights reserved.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.locutil2;

import org.pi4.locutil2.GeoPosition;

import junit.framework.TestCase;

public class GeoPositionTest extends TestCase {

	/*
	 * Test method for 'org.pi4.locutil2.GeoPosition.equals(Object)'
	 */
	public void testEqualsObject() {
		GeoPosition pos1 = new GeoPosition(1.0, 1.0, 1.0, 90);
		GeoPosition pos2 = new GeoPosition(1.0, 1.0, 1.0, 90);
		GeoPosition pos3 = new GeoPosition(1.0, 1.0, 1.0, 80);
		GeoPosition pos4 = new GeoPosition(1.0, 2.0, 1.0, 90);
		assertEquals(pos1, pos2);
		assertFalse(pos1.equals(pos3));
		assertFalse(pos1.equals(pos4));
		assertFalse(pos2.equals(pos3));
		assertFalse(pos2.equals(pos4));
		assertFalse(pos3.equals(pos4));
	}

	/*
	 * Test method for 'org.pi4.loceva.util.GeoPosition.equalsWithoutOrientation(Object)'
	 */
	public void testEqualsWithoutOrientation() {
		GeoPosition pos1 = new GeoPosition(1.0, 1.0, 1.0, 90);
		GeoPosition pos2 = new GeoPosition(1.0, 1.0, 1.0, 90);
		GeoPosition pos3 = new GeoPosition(1.0, 1.0, 1.0, 80);
		GeoPosition pos4 = new GeoPosition(1.0, 2.0, 1.0, 90);
		assertTrue(pos1.equalsWithoutOrientation(pos2));
		assertTrue(pos1.equalsWithoutOrientation(pos3));
		assertFalse(pos1.equalsWithoutOrientation(pos4));
		assertTrue(pos2.equalsWithoutOrientation(pos3));
		assertFalse(pos2.equalsWithoutOrientation(pos4));
		assertFalse(pos3.equalsWithoutOrientation(pos4));
	}

	/*
	 * Test method for 'org.pi4.loceva.util.GeoPosition.addPosition(GeoPosition)'
	 */
	public void testAddPosition() {
		GeoPosition pos1 = new GeoPosition(1.0, 2.0, 3.0, 90);
		GeoPosition res = pos1.addPosition(new GeoPosition(-1.0, -2.0, -5.0, 100));
		assertEquals(new GeoPosition(0.0, 0.0, -2.0, 90), res);
	}

	/*
	 * Test method for 'org.pi4.loceva.util.GeoPosition.stretch(double)'
	 */
	public void testStretch() {
		GeoPosition pos1 = new GeoPosition(1.0, 2.0, 3.0, 90);
		GeoPosition res = pos1.stretch(2.0);
		assertEquals(new GeoPosition(2.0, 4.0, 6.0, 90), res);
	}

}
