/*
 * This file is part of Locutil2.
 * 
 * Copyright (c) 2007 Thomas King <king@informatik.uni-mannheim.de>,
 * University of Mannheim, Germany
 * 
 * All rights reserved.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.locutil2.trace;

import junit.framework.*;
import java.io.File;
import java.util.ArrayList;

import org.pi4.locutil1.MACAddress;
import org.pi4.locutil2.GeoPosition;

/**
 * Test cases for Parser.
 */
public class ParserTest extends TestCase {
	
	/**
	 * Tests parsing our sample trace file.
	 */
	public void testParsing() throws Exception {
		Parser parser = new Parser(new File("test/org/pi4/locutil2/trace/Trace.txt"));
		parser.setPrecision(45.0);
		ArrayList<TraceEntry> trace = parser.parse();
		
		TraceEntry entry = trace.get(0);
		assertEquals(new GeoPosition(0.0, 0.0, 0.0, 0.0), entry.getGeoPosition());
		assertEquals(new MACAddress(new short[]{0, 0, 0, 0, 0, 0}), entry.getId());
		MACAddress mac = new MACAddress(new short[]{1, 2, 3, 4, 5, 6});
		assertTrue(entry.getSignalStrengthSamples().containsKey(mac));
		assertEquals(-50.0, entry.getSignalStrengthSamples().getFirstSignalStrength(mac), 0.0);
		
		entry = trace.get(2);
		assertEquals(new GeoPosition(1.0, 1.0, 1.0, 180.0), entry.getGeoPosition());
		assertEquals(new MACAddress(new short[]{1, 1, 1, 1, 1, 1}), entry.getId());
		mac = new MACAddress(new short[]{7, 8, 9, 0, 1, 2});
		assertTrue(entry.getSignalStrengthSamples().containsKey(mac));
		assertEquals(-50.0, entry.getSignalStrengthSamples().getFirstSignalStrength(mac), 0.0);
	}
}
