/*
 * This file is part of Locutil2.
 * 
 * Copyright (c) 2007 Thomas King <king@informatik.uni-mannheim.de>,
 * University of Mannheim, Germany
 * 
 * All rights reserved.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.locutil2.trace.macfilter;

import java.io.File;
import java.util.ArrayList;

import junit.framework.TestCase;

import org.pi4.locutil1.MACAddress;
import org.pi4.locutil2.trace.Parser;
import org.pi4.locutil2.trace.TraceEntry;
import org.pi4.locutil2.trace.macfilter.MacFilterExplizit;

/**
 * Test cases for MacFilter.
 */
public class MacFilterTest extends TestCase {
	/**
	 * Tests the MacFilter class.
	 */
	public void testMacFilter() throws Exception {
		Parser parser = new Parser(new File("test/org/pi4/loceva/Trace.txt"));
		MacFilterExplizit mf = new MacFilterExplizit();
		MACAddress mac = new MACAddress(new short[]{1, 2, 3, 4, 5, 6});
		mf.add(mac);
		parser.setMacFilter(mf);
		ArrayList<TraceEntry> trace = parser.parse();
		TraceEntry entry = trace.get(0);
		assertTrue(entry.getSignalStrengthSamples().containsKey(mac));
		
		MACAddress mac2 = new MACAddress(new short[]{7, 8, 9, 0, 1, 2});
		assertFalse(entry.getSignalStrengthSamples().containsKey(mac2));
	}
	
	public void testToString() {
		MacFilterExplizit filter = new MacFilterExplizit();
		filter.add(new MACAddress(new short[]{1, 2, 3, 4, 5, 6}));
		assertEquals("MacFilterExplizit: 01:02:03:04:05:06", filter.toString());
		filter.add(new MACAddress(new short[]{7, 8, 9, 10, 11, 12}));
		System.out.println(filter.toString());
		assertEquals(", ", filter.toString().substring(36, 38));
		assertEquals((2 * 17) + 2 + 19, filter.toString().length());
	}
}
